# (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from __future__ import print_function

# from django.db import models
# from django.utils.translation import ugettext_lazy as _

# Create your models here.
